==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QMediaPlayerControl_shell.h <==
#ifndef QMEDIAPLAYERCONTROL_SHELL_H
#define QMEDIAPLAYERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaplayercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediacontent.h>
#include <QtMultimedia/qmediaplayer.h>
#include <QtMultimedia/qmediatimerange.h>
#include <QtJambi/RegistryAPI>


class QMediaPlayerControl_shell : public QMediaPlayerControl, public QtJambiShellInterface
{
public:
    QMediaPlayerControl_shell(QObject* parent0 = nullptr);
    ~QMediaPlayerControl_shell() override;

    QMediaTimeRange availablePlaybackRanges() const override;
    int bufferStatus() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isAudioAvailable() const override;
    bool isMuted() const override;
    bool isSeekable() const override;
    bool isVideoAvailable() const override;
    QMediaContent media() const override;
    QMediaPlayer::MediaStatus mediaStatus() const override;
    const QIODevice* mediaStream() const override;
    void pause() override;
    void play() override;
    qreal playbackRate() const override;
    qint64 position() const override;
    void setMedia(const QMediaContent& media0, QIODevice* stream1) override;
    void setMuted(bool mute0) override;
    void setPlaybackRate(qreal rate0) override;
    void setPosition(qint64 position0) override;
    void setVolume(int volume0) override;
    QMediaPlayer::State state() const override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    int volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaPlayerControl_access : public QMediaPlayerControl
{
    jobject __qt_availablePlaybackRanges(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bufferStatus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_duration(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isAudioAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isMuted(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSeekable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isVideoAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_media(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_mediaStatus(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_mediaStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_pause(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_play(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jdouble __qt_playbackRate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_position(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setMedia_cref_QMediaContent_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID media0, QtJambiNativeID stream1);
    void __qt_setMuted_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean mute0);
    void __qt_setPlaybackRate_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble rate0);
    void __qt_setPosition_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong position0);
    void __qt_setVolume_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint volume0);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_volume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIAPLAYERCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QMediaPlayerControl_shell.h <==
#ifndef QMEDIAPLAYERCONTROL_SHELL_H
#define QMEDIAPLAYERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediaplayercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediacontent.h>
#include <QtMultimedia/qmediaplayer.h>
#include <QtMultimedia/qmediatimerange.h>
#include <QtJambi/RegistryAPI>


class QMediaPlayerControl_shell : public QMediaPlayerControl, public QtJambiShellInterface
{
public:
    QMediaPlayerControl_shell(QObject* parent0 = nullptr);
    ~QMediaPlayerControl_shell() override;

    QMediaTimeRange availablePlaybackRanges() const override;
    int bufferStatus() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isAudioAvailable() const override;
    bool isMuted() const override;
    bool isSeekable() const override;
    bool isVideoAvailable() const override;
    QMediaContent media() const override;
    QMediaPlayer::MediaStatus mediaStatus() const override;
    const QIODevice* mediaStream() const override;
    void pause() override;
    void play() override;
    qreal playbackRate() const override;
    qint64 position() const override;
    void setMedia(const QMediaContent& media0, QIODevice* stream1) override;
    void setMuted(bool mute0) override;
    void setPlaybackRate(qreal rate0) override;
    void setPosition(qint64 position0) override;
    void setVolume(int volume0) override;
    QMediaPlayer::State state() const override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    int volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaPlayerControl_access : public QMediaPlayerControl
{
    jobject __qt_availablePlaybackRanges_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bufferStatus_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_duration_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isAudioAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isMuted_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSeekable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isVideoAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_media_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_mediaStatus_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_mediaStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_pause(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_play(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jdouble __qt_playbackRate_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_position_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setMedia_cref_QMediaContent_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID media0, QtJambiNativeID stream1);
    void __qt_setMuted_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean mute0);
    void __qt_setPlaybackRate_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble rate0);
    void __qt_setPosition_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong position0);
    void __qt_setVolume_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint volume0);
    jint __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_volume_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMEDIAPLAYERCONTROL_SHELL_H
